@@ -3,6 +3,8 @@ use 5.010;
 use strict;
 use warnings;
 
+use parent 'RxPerl::Base';
+
 use RxPerl ':all';
 
 use IO::Async::Timer::Countdown;
@@ -13,7 +15,9 @@ use Exporter 'import';
 our @EXPORT_OK = @RxPerl::EXPORT_OK;
 our %EXPORT_TAGS = %RxPerl::EXPORT_TAGS;
 
-our $VERSION = "v6.0.1";
+our $VERSION = "v6.6.0";
+
+our $promise_class;
 
 foreach my $func_name (@EXPORT_OK) {
     set_subname __PACKAGE__."::$func_name", \&{$func_name};
